FFix.Terminal (ffix v0.1.0)

Copy Markdown View Source

Opaque handle for a sink-ending pipeline.

Terminal values are produced by sink filters and can be attached to a graph with FFix.graph(terminals: [...]) when a branch is meant to end inside the filtergraph instead of becoming an output mapping.

Summary

Types

t()

@opaque t()